about summary refs log tree commit diff
path: root/support/check.h
diff options
context:
space:
mode:
authorFlorian Weimer <fweimer@redhat.com>2016-12-31 12:20:49 +0100
committerFlorian Weimer <fweimer@redhat.com>2016-12-31 18:51:15 +0100
commit039c5a05cc905e3d48392e7ea9f85e339b7c068b (patch)
tree2d69efafb74a99d94b13b98eaab09d9e1d0e505c /support/check.h
parent5707a64d9462001f9c7c2e02d3f52cf8b0181658 (diff)
downloadglibc-039c5a05cc905e3d48392e7ea9f85e339b7c068b.tar.gz
glibc-039c5a05cc905e3d48392e7ea9f85e339b7c068b.tar.xz
glibc-039c5a05cc905e3d48392e7ea9f85e339b7c068b.zip
support: Use support_record_failure consistently
This causes more test programs to link in the support_record_failure
function, which triggers an early call to mmap from an ELF
constructor, but this should not have side effects intefering
with the functionality actually under test (unlike, say, a call
to malloc).
Diffstat (limited to 'support/check.h')
-rw-r--r--support/check.h10
1 files changed, 7 insertions, 3 deletions
diff --git a/support/check.h b/support/check.h
index 92cb5d9934..129bff2dbe 100644
--- a/support/check.h
+++ b/support/check.h
@@ -23,15 +23,19 @@
 
 __BEGIN_DECLS
 
-/* Print failure message to standard output and return 1.  */
+/* Record a test failure, print the failure message to standard output
+   and return 1.  */
 #define FAIL_RET(...) \
   return support_print_failure_impl (__FILE__, __LINE__, __VA_ARGS__)
 
-/* Print failure message and terminate the process with STATUS.  */
+/* Print the failure message and terminate the process with STATUS.
+   Record a the process as failed if STATUS is neither EXIT_SUCCESS
+   nor EXIT_UNSUPPORTED.  */
 #define FAIL_EXIT(status, ...) \
   support_exit_failure_impl (status, __FILE__, __LINE__, __VA_ARGS__)
 
-/* Print failure message and terminate with exit status 1.  */
+/* Record a test failure, print the failure message and terminate with
+   exit status 1.  */
 #define FAIL_EXIT1(...) \
   support_exit_failure_impl (1, __FILE__, __LINE__, __VA_ARGS__)